@@ -2,5 +2,5 @@ package Book;
 use Object::Simple;
 
 sub title : Attr { default => 1 }
-Object::Simple->end;
+Object::Simple->build_class;
 
